; Dark Star, ZX Spectrum.

; These sources are reconstructed from a disassembly using the routine names from a pre-release early version.
; The code they generate is not exactly the same as the original binary, I've moved sections around during the testing
; process to make sure that the source code is accurate - to change the addresses of labels, basically, so that things
; don't just accidentally work because they happen to be at the same address as before and some constants that should be
; labels are therefore giving the "right" values but only by accident. I've stripped out some tedious bits of redundant
; code that were added originally to make disassembly harder - they did. Should have known back in 1985 that they'd
; trip me up in the future, sheesh.

; The game remains the same, aside from being frame-locked to take advantage of emulators that can run the Z80 in turbo
; mode. You can disable that by commenting out the option, a few lines below this. I also fixed a minor bug, you can
; restore that if you like.

; Assembly time options. Comment these out to make them ineffective

; Which version?
;bFreeVersion            equ true                        ; If enabled, we're generating the free version

bAnalogDefault          equ true                        ; Default to the joystick

bFrameLock              equ true                        ; We lock to the video frame

;bDontFixBug             equ true                        ; Leave the (minor) bug alone

bCompressForTape        equ true                        ; Generate compressed data

; Change this to point somewhere suitable on your computer. Note that Windows 7 doesn't let you write into the root directory!

OutputDir               equ "c:\projects\games\dark star\bin"  ; This needs to exist

; Include the equates

                        include "ds_equ.inc"

                        include "ds_data.inc"

                        ; Include the front-end code

                        include "ds_front.inc"

                        ; Include the game-irq code

                        include "ds_irq.inc"

                        ; Include the user-defined key code

                        include "ds_udk.inc"

                        ; Include the maths code

                        include "ds_maths.inc"

                        ; Include various utilities

                        include "ds_utils.inc"

                        ; The player's code

                        include "ds_player.inc"

                        ; Include the drawing routines

                        include "ds_draw.inc"

                        ; Include the stars

                        include "ds_stars.inc"

                        ; Include the projectiles (player's weapon)

                        include "ds_proj.inc"

                        ; Include the map, etc

                        include "ds_map.inc"

                        ; Include the object code

                        include "ds_objects.inc"

                        ; Include the game-code

                        include "ds_game.inc"

; Tell the emulator that every byte of memory is fair game, including writes to the rom
; because the code sometimes does that.

                        mem_smc $0000,$10000

; These commands tell Zeus where to put the code it generates

; Warn if there are any strange options set

        if enabled bAnalogDefault
          zeusprint "                                               WARNING! Analogue Joystick is the default"
        endif

; This command tells Zeus where to put the code it generates. As a szx file...
; Zeus's internal emulator needs you to generate a szx file somewhere in order to emulate correctly

        if def bDontWriteFiles
                        output_szx OutputDir+"\dsunusual.szx",$0000,Reset       ; The szx file
          zeusprint "********************************************   WARNING! No files written!"
        else
          if enabled bFreeVersion
                        output_szx OutputDir+"\dsfree.szx",$0000,Reset          ; The szx file
          zeusprint "                                               Written free version"
          else
                        output_szx OutputDir+"\ds.szx",$0000,Reset              ; The szx file
          zeusprint "                                               Written full version"
          endif
        endif


;                        output_bin OutputDir+"\ds_new.bin",$4000,$C000      ; The binary file

; Messy stuff at the end

        if ZEUSVER < 25
            zeuserror "Please upgrade Zeus - the latest version can be found at www.desdes.com/products/oldfiles"
          if ZEUSVER < 25
            zeuserror "There are problems with the Spectrum emulation in this version of Zeus"
          endif
          if ZEUSVER < 11
            zeuserror "This version of Zeus doesn't understand the DG pseudo-op"
          endif
        endif

; Build instead the compressed data for the loader

        if enabled bCompressForTape and (ZEUSVER >= 26)
          zeuscompress $5B00,Save_Limit,Reset,$5B00,1  ; This builds a block of data which you load at $5B00 and then call at $5B00 (the 1 means flash border during decompression)
          output_bin OutputDir+"\ds_load.bin",$5B00,$5E00           ; The loader data
          zeusprinthex "You need to save the block starting at $5B00 and call it at $5B00. Highest required byte's address stored at $5B02"
        else
;          zeusprinthex "( You need only save memory below: ", Save_Limit,"during tape saves. Only the stack and score-reporting live above: ", Ye_End, "Call ",Reset," to start )"
        endif

